==> api-vertx-client-0.7.20.6.1-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/MosaicRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.AccountIds;
import io.nem.sdk.openapi.vertx.model.ModelError;
import io.nem.sdk.openapi.vertx.model.MosaicIds;
import io.nem.sdk.openapi.vertx.model.MosaicInfoDTO;
import io.nem.sdk.openapi.vertx.model.MosaicsInfoDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2020-01-01T18:24:23.294947664-03:00[America/Argentina/Buenos_Aires]")
public class MosaicRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.MosaicRoutesApi delegate;

	public MosaicRoutesApi(io.nem.sdk.openapi.vertx.api.MosaicRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.MosaicRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get mosaic information
     * Gets the mosaic definition for a given mosaic identifier.
     * @param mosaicId Mosaic identifier. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaic(String mosaicId, Handler<AsyncResult<MosaicInfoDTO>> resultHandler) {
        delegate.getMosaic(mosaicId, resultHandler);
    }

    /**
     * Get mosaic information
     * Gets the mosaic definition for a given mosaic identifier.
     * @param mosaicId Mosaic identifier. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicInfoDTO> rxGetMosaic(String mosaicId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaic(mosaicId, fut);
        }));
    }
    /**
     * Get mosaics information for an array of mosaics
     * Gets an array of mosaic definition.
     * @param mosaicIds  (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaics(MosaicIds mosaicIds, Handler<AsyncResult<List<MosaicInfoDTO>>> resultHandler) {
        delegate.getMosaics(mosaicIds, resultHandler);
    }

    /**
     * Get mosaics information for an array of mosaics
     * Gets an array of mosaic definition.
     * @param mosaicIds  (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<MosaicInfoDTO>> rxGetMosaics(MosaicIds mosaicIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaics(mosaicIds, fut);
        }));
    }
    /**
     * Get mosaics created by an account
     * Gets an array of mosaics created for a given account address.
     * @param accountId Account public key or address. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicsFromAccount(String accountId, Handler<AsyncResult<MosaicsInfoDTO>> resultHandler) {
        delegate.getMosaicsFromAccount(accountId, resultHandler);
    }

    /**
     * Get mosaics created by an account
     * Gets an array of mosaics created for a given account address.
     * @param accountId Account public key or address. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicsInfoDTO> rxGetMosaicsFromAccount(String accountId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicsFromAccount(accountId, fut);
        }));
    }
    /**
     * Get mosaics created for given array of addresses
     * Gets mosaics created for a given array of addresses.
     * @param accountIds  (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicsFromAccounts(AccountIds accountIds, Handler<AsyncResult<MosaicsInfoDTO>> resultHandler) {
        delegate.getMosaicsFromAccounts(accountIds, resultHandler);
    }

    /**
     * Get mosaics created for given array of addresses
     * Gets mosaics created for a given array of addresses.
     * @param accountIds  (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicsInfoDTO> rxGetMosaicsFromAccounts(AccountIds accountIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicsFromAccounts(accountIds, fut);
        }));
    }

    public static MosaicRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.MosaicRoutesApi arg) {
        return arg != null ? new MosaicRoutesApi(arg) : null;
    }
}

==> api-vertx-client-0.7.21-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/MosaicRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.AccountIds;
import io.nem.sdk.openapi.vertx.model.ModelError;
import io.nem.sdk.openapi.vertx.model.MosaicIds;
import io.nem.sdk.openapi.vertx.model.MosaicInfoDTO;
import io.nem.sdk.openapi.vertx.model.MosaicsInfoDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2019-11-23T10:26:45.594287+01:00[Europe/Madrid]")
public class MosaicRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.MosaicRoutesApi delegate;

	public MosaicRoutesApi(io.nem.sdk.openapi.vertx.api.MosaicRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.MosaicRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get mosaic information
     * Gets the mosaic definition for a given mosaic identifier.
     * @param mosaicId Mosaic identifier. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaic(String mosaicId, Handler<AsyncResult<MosaicInfoDTO>> resultHandler) {
        delegate.getMosaic(mosaicId, resultHandler);
    }

    /**
     * Get mosaic information
     * Gets the mosaic definition for a given mosaic identifier.
     * @param mosaicId Mosaic identifier. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicInfoDTO> rxGetMosaic(String mosaicId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaic(mosaicId, fut);
        }));
    }
    /**
     * Get mosaics information for an array of mosaics
     * Gets an array of mosaic definition.
     * @param mosaicIds  (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaics(MosaicIds mosaicIds, Handler<AsyncResult<List<MosaicInfoDTO>>> resultHandler) {
        delegate.getMosaics(mosaicIds, resultHandler);
    }

    /**
     * Get mosaics information for an array of mosaics
     * Gets an array of mosaic definition.
     * @param mosaicIds  (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<MosaicInfoDTO>> rxGetMosaics(MosaicIds mosaicIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaics(mosaicIds, fut);
        }));
    }
    /**
     * Get mosaics created by an account
     * Gets an array of mosaics created for a given account address.
     * @param accountId Account public key or address. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicsFromAccount(String accountId, Handler<AsyncResult<MosaicsInfoDTO>> resultHandler) {
        delegate.getMosaicsFromAccount(accountId, resultHandler);
    }

    /**
     * Get mosaics created by an account
     * Gets an array of mosaics created for a given account address.
     * @param accountId Account public key or address. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicsInfoDTO> rxGetMosaicsFromAccount(String accountId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicsFromAccount(accountId, fut);
        }));
    }
    /**
     * Get mosaics created for given array of addresses
     * Gets mosaics created for a given array of addresses.
     * @param accountIds  (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicsFromAccounts(AccountIds accountIds, Handler<AsyncResult<MosaicsInfoDTO>> resultHandler) {
        delegate.getMosaicsFromAccounts(accountIds, resultHandler);
    }

    /**
     * Get mosaics created for given array of addresses
     * Gets mosaics created for a given array of addresses.
     * @param accountIds  (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicsInfoDTO> rxGetMosaicsFromAccounts(AccountIds accountIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicsFromAccounts(accountIds, fut);
        }));
    }

    public static MosaicRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.MosaicRoutesApi arg) {
        return arg != null ? new MosaicRoutesApi(arg) : null;
    }
}
